﻿/**
 * @file digo 插件：使用 Babel 编译 ES6/JSX
 * @author xuld <xuld@vip.qq.com>
 * @license MIT
 * @see http://babeljs.io/docs/usage/options/
 */
var babel = require("babel-core");

module.exports = function Babel(file, options) {

    // 设置默认值。
    options = Object.assign({
        filename: file.srcPath,
        sourceMaps: file.sourceMap,
        inputSourceMap: file.sourceMapData,
        babelrc: false,
        compact: false
    }, options);

    // 更改扩展名。
    file.ext = ".js";

    // 生成。
    try {
        var result = babel.transform(file.content, options);
    } catch (e) {
        var log = {
            plugin: Babel.name,
            source: e.codeFrame,
            error: e
        };
        try {
            var m = /^(.*?): (.*)\s*\(\d+:\d+\)$/.exec(e.message);
            log.message = m[2];
            log.fileName = m[1];
            log.startLine = e.loc && e.loc.line - 1;
            log.startColumn = e.loc && e.loc.column;
        } catch (e2) { }
        return file.error(log);
    }

    // 保存。
    file.content = result.code;
    if (result.map) {
        for(var i = 0; i < result.map.sources.length; i++) {
            result.map.sources[i] = file.resolve(result.map.sources[i]);
        }
        file.sourceMapData = result.map;
    }
    file.ast = result.ast;
};
